#
# spec file for package octave-forge-nurbs
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  nurbs
Name:           octave-forge-%{octpkg}
Version:        1.4.3
Release:        2.1
Summary:        Routines for Non-Uniform Rational B-Splines for Octave
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://octave.sourceforge.io/%{octpkg}/
Source0:        https://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM nurbs-openmp.patch -- Fix build with openmp
Patch1:         nurbs-openmp.patch
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
BuildRequires:  octave-devel
Requires:       octave-cli >= 5.1.0

%description
Collection of routines for the creation, and manipulation of
Non-Uniform Rational B-Splines (NURBS).
This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
pushd %{octpkg}-%{version}
%patch -P 1 -p1
popd
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%{octpackages_dir}/%{octpkg}-%{version}
%{octlib_dir}/%{octpkg}-%{version}

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Sep 15 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.4.3:
  * inst/nrbctrlplot: allow the number of points for the plot as input
  * inst/nrbkntplot: allow the number of points for the plot as input
  * inst/nrbmak: added consistency check
* Thu Mar 25 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.4.2:
  * remove use of deprecated functionality in oct-files
- Summary of important user-visible changes for nurbs 1.4.1:
  * inst/nrbglue: added new function
  * inst/nrbinverse: add a way to recognize non-convergence
- Summary of important user-visible changes for nurbs 1.4.0:
  * inst/basiskntins: return the identity when there is no
    insertion
  * inst/nrbderiv: 3rd and 4th order derivatives
  * inst/nrbdeval: 3rd and 4th order derivatives
  * inst/nrbruled: extended to trivariates
  * inst/nrbmak: added the possibility to normalize the knot
    vector
  * inst/vecnormalize: renamed the old function vecnorm
- Summary of important user-visible changes for nurbs 1.3.14:
  * inst/nrbextract: possibility to extract a list of boundary
    sides
  * inst/nrbmultipatch: added tolerance as an optional argument
  * inst/nrbspheretiling: added new function
  * inst/nrbspheretile: added new function
- Switch to using _service to download directly from upstream
  mercurial repository since source tarballs are no longer
  released.
- Bump minimum required octave version to 5.1 in keeping with
  upstream.
* Wed Nov 27 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.3.13:
  * inst/aveknt.m: added new function
  * inst/nrbclamp.: added new function
  * inst/nrbmodp.m: added new function
  * inst/nrbmodw.m: added new function
  * inst/nrbeval_der_p.m: added new function
  * inst/nrbeval_der_w.m: added new function
  * inst/nrbsquare.m: added new function
  * inst/bspinterpcrv.m: added new function
  * inst/bspinterpsurf.m: added new function
  * inst/nrbinverse.m: added new function
  * inst/nrbbasisfun.m: faster version for cell-arrays. Working
    version for volumes
  * inst/nrbbasisfunder.m: faster version for cell-arrays. Working
    version for volumes
  * inst/nrbnumbasisfun.m: faster version for cell-arrays. Working
    version for volumes. Now using 0-based indexing for cuves
    (different from basisfun).
- Update to version 1.3.12:
  * nrbmultipatch: check if two faces match more accurately
- Update to version 1.3.11:
  * nrbextract, nrbmultipatch: generalized for curves
  * inst/deg2rad, inst/rad2deg: removed functions from the package
* Wed Sep  9 2015 dmitry_r@opensuse.org
- Update to version 1.3.10
  * Compatibility with Octave 4.0
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 1.3.9
- Fix build with openmp
  * nurbs-openmp.patch
